@@ -1,5 +1,5 @@
 from .str2num import str2num
 
 __all__ = [
-    'str2num'
+    str2num.__name__,
 ]
